***********************
The sherpa.astro module
***********************

.. currentmodule:: sherpa.astro

.. automodule:: sherpa.astro

   .. rubric:: Constants

   .. autosummary::
      :toctree: api

      charge_e
      hc
